Installation
============

Create a virtual environment with Python >=3.7,<=3.9, and install from git:

.. code-block::

    $ pip install git+https://github.com/btcross26/genestboost.git

Alternatively, you can install directly from PyPI:

.. code-block:: bash

    $ pip install genestboost

Or from conda-forge:

.. code-block:: bash

    $ conda install -c conda-forge genestboost
